@@ -2,6 +2,7 @@
 from __future__ import annotations
 
 from enum import IntEnum
+from typing import Any
 
 
 class AirzoneStages(IntEnum):
@@ -9,28 +10,46 @@ class AirzoneStages(IntEnum):
 
     UNKNOWN = -1
 
-    EMPTY = 0
+    Off = 0
     Air = 1
     Radiant = 2
     Combined = 3
 
     @classmethod
-    def _missing_(cls, value):
+    def _missing_(cls, value: Any) -> AirzoneStages:
         return cls.UNKNOWN
 
     def exists(self) -> bool:
         """Return if Airzone Stage exits."""
-        return self.value != self.EMPTY
+        return self.value != self.Off
 
     def to_list(self) -> list[AirzoneStages]:
         """Convert AirzoneStages value to list."""
         if self.value == self.Combined:
-            return [AirzoneStages.Air, AirzoneStages.Radiant, AirzoneStages.Combined]
+            return [
+                AirzoneStages.Off,
+                AirzoneStages.Air,
+                AirzoneStages.Radiant,
+                AirzoneStages.Combined,
+            ]
         if self.value in (self.Air, self.Radiant):
-            return [self]
+            return [AirzoneStages.Off, self]
         return []
 
 
+class GrilleAngle(IntEnum):
+    """Airzone grille angles."""
+
+    DEG_90 = 0
+    DEG_50 = 1
+    DEG_45 = 2
+    DEG_40 = 3
+
+    @classmethod
+    def _missing_(cls, value: Any) -> GrilleAngle:
+        return cls.DEG_90
+
+
 class OperationMode(IntEnum):
     """Airzone operation modes."""
 
@@ -44,7 +63,7 @@ class OperationMode(IntEnum):
     AUTO = 7
 
     @classmethod
-    def _missing_(cls, value):
+    def _missing_(cls, value: Any) -> OperationMode:
         return cls.UNKNOWN
 
 
@@ -62,7 +81,7 @@ class SystemType(IntEnum):
     ZS6 = 7
 
     @classmethod
-    def _missing_(cls, value):
+    def _missing_(cls, value: Any) -> SystemType:
         return cls.UNKNOWN
 
     def __str__(self) -> str:
@@ -98,7 +117,7 @@ class ThermostatType(IntEnum):
     Think = 4
 
     @classmethod
-    def _missing_(cls, value):
+    def _missing_(cls, value: Any) -> ThermostatType:
         return cls.UNKNOWN
 
     def __str__(self) -> str:
@@ -133,7 +152,7 @@ class WebServerInterface(IntEnum):
     WIFI = 2
 
     @classmethod
-    def _missing_(cls, value):
+    def _missing_(cls, value: Any) -> WebServerInterface:
         return cls.UNKNOWN
 
 
@@ -146,7 +165,7 @@ class WebServerType(IntEnum):
     AIDOO = 2
 
     @classmethod
-    def _missing_(cls, value):
+    def _missing_(cls, value: Any) -> WebServerType:
         return cls.UNKNOWN
 
     def __str__(self) -> str:
